# Apps

`clinlp` includes some (web)apps that allow you to interact with the library.

## Information Extraction Demo

```{include} ../../src/clinlp_apps/ie_demo/README.md
:start-after: <!-- start_include_in_docs -->
```
